@@ -97,6 +97,19 @@ class TestKyotoTycoonConnection(object):
         time.sleep(1)
         eq_({}, connection.get_bulk(data.keys()))
 
+    def test_query_with_db_index(self):
+        connection = KyotoTycoonConnection()
+        data = {}
+        for n in range(3):
+            data[uuid.uuid1().hex] = n
+
+        connection.set_bulk(data, db_index=1)
+
+        eq_(data, connection.get_bulk(data.keys(), db_index=1))
+        connection.remove_bulk(data.keys(), db_index=1)
+
+        eq_({}, connection.get_bulk(data.keys(), db_index=1))
+
 
 class TestKyotoTycoonPoolConnection(object):
     def setUp(self):
@@ -129,3 +142,14 @@ class TestKyotoTycoonPoolConnection(object):
             client.set_bulk(data)
             eq_(1, client.remove_bulk(data.keys()))
             eq_({}, client.get_bulk(data.keys()))
+
+    def test_query_with_db_index(self):
+        data = {uuid.uuid1().hex: 1}
+
+        with self._pool.connection() as client:
+            client.set_bulk(data, db_index=1)
+
+            eq_(data, client.get_bulk(data.keys(), db_index=1))
+            client.remove_bulk(data.keys(), db_index=1)
+
+            eq_({}, client.get_bulk(data.keys(), db_index=1))
